# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from team_member_server_sdk.api.team_member_api import TeamMemberApi  # noqa: E501


class TestTeamMemberApi(unittest.IsolatedAsyncioTestCase):
    """TeamMemberApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = TeamMemberApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_activate_team_member_v1_team_member_activate_post(self) -> None:
        """Test case for activate_team_member_v1_team_member_activate_post

        Activate Team Member  # noqa: E501
        """
        pass

    async def test_disable_team_member_v1_team_member_disable_post(self) -> None:
        """Test case for disable_team_member_v1_team_member_disable_post

        Disable Team Member  # noqa: E501
        """
        pass

    async def test_enable_team_member_v1_team_member_enable_post(self) -> None:
        """Test case for enable_team_member_v1_team_member_enable_post

        Enable Team Member  # noqa: E501
        """
        pass

    async def test_get_team_member_access_v1_team_member_access_get_post(self) -> None:
        """Test case for get_team_member_access_v1_team_member_access_get_post

        Get Team Member access  # noqa: E501
        """
        pass

    async def test_get_team_members_amount_v1_team_member_count_post(self) -> None:
        """Test case for get_team_members_amount_v1_team_member_count_post

        Get Team Members amount  # noqa: E501
        """
        pass

    async def test_get_team_members_v1_team_member_list_post(self) -> None:
        """Test case for get_team_members_v1_team_member_list_post

        Get Team Members  # noqa: E501
        """
        pass

    async def test_invite_team_member_v1_team_member_invite_post(self) -> None:
        """Test case for invite_team_member_v1_team_member_invite_post

        Invite new Team Member  # noqa: E501
        """
        pass

    async def test_remove_team_members_v1_team_member_delete_post(self) -> None:
        """Test case for remove_team_members_v1_team_member_delete_post

        Remove Team Member  # noqa: E501
        """
        pass

    async def test_resend_invitation_email_v1_team_member_email_resend_post(self) -> None:
        """Test case for resend_invitation_email_v1_team_member_email_resend_post

        Resend invitation email  # noqa: E501
        """
        pass

    async def test_update_team_members_v1_team_member_update_post(self) -> None:
        """Test case for update_team_members_v1_team_member_update_post

        Update Team Member  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, conlist, validator
from team_member_server_sdk.models.team_member_role_response import TeamMemberRoleResponse

class WrappedResponseListTeamMemberRoleResponse(BaseModel):
    """
    WrappedResponseListTeamMemberRoleResponse
    """
    done: Optional[StrictBool] = True
    result: conlist(TeamMemberRoleResponse) = Field(...)
    __properties = ["done", "result"]

    @validator('done')
    def done_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('true',):
            raise ValueError("must be one of enum values ('true')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WrappedResponseListTeamMemberRoleResponse:
        """Create an instance of WrappedResponseListTeamMemberRoleResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in result (list)
        _items = []
        if self.result:
            for _item in self.result:
                if _item:
                    _items.append(_item.to_dict())
            _dict['result'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WrappedResponseListTeamMemberRoleResponse:
        """Create an instance of WrappedResponseListTeamMemberRoleResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WrappedResponseListTeamMemberRoleResponse.parse_obj(obj)

        _obj = WrappedResponseListTeamMemberRoleResponse.parse_obj({
            "done": obj.get("done") if obj.get("done") is not None else True,
            "result": [TeamMemberRoleResponse.from_dict(_item) for _item in obj.get("result")] if obj.get("result") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from team_member_server_sdk.models.settings_operation import SettingsOperation  # noqa: E501

class TestSettingsOperation(unittest.TestCase):
    """SettingsOperation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSettingsOperation(self):
        """Test SettingsOperation"""
        # inst = SettingsOperation()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Mentortools Team Member Server

    Mentortools service for Team Members

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0+2444294943"

# Define package exports
__all__ = [
    "ServerRequestsApi",
    "TeamMemberApi",
    "TeamMemberRoleApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ActionCode",
    "ActionOperation",
    "ActionToUpdate",
    "ActivateTeamMemberRequest",
    "AddTeamMemberRoleRequest",
    "DisableTeamMemberRequest",
    "EnableTeamMemberRequest",
    "EntitySettingsToUpdate",
    "EntityType",
    "HTTPValidationError",
    "InviteTeamMemberRequest",
    "LocationInner",
    "PortalMemberSchema",
    "RemoveTeamMemberRequest",
    "RemoveTeamMemberRoleRequest",
    "ResendInvitationEmailRequest",
    "ScopeSchema",
    "SettingsOperation",
    "TeamMemberAccessResponse",
    "TeamMemberActionsRequest",
    "TeamMemberAmountRequest",
    "TeamMemberRequest",
    "TeamMemberResponse",
    "TeamMemberRoleResponse",
    "TeamMemberRoleSchema",
    "TeamMemberRoleValuesToUpdate",
    "TeamMemberValuesToUpdate",
    "UpdateTeamMemberRequest",
    "UpdateTeamMemberRoleActionsRequest",
    "UpdateTeamMemberRoleEntitySettingsRequest",
    "UpdateTeamMemberRoleRequest",
    "ValidationError",
    "WrappedResponseInt",
    "WrappedResponseListTeamMemberResponse",
    "WrappedResponseListTeamMemberRoleResponse",
    "WrappedResponseTeamMemberAccessResponse",
    "WrappedResponseTeamMemberResponse",
    "WrappedResponseTeamMemberRoleResponse",
]

# import apis into sdk package
from team_member_server_sdk.api.server_requests_api import ServerRequestsApi as ServerRequestsApi
from team_member_server_sdk.api.team_member_api import TeamMemberApi as TeamMemberApi
from team_member_server_sdk.api.team_member_role_api import TeamMemberRoleApi as TeamMemberRoleApi

# import ApiClient
from team_member_server_sdk.api_response import ApiResponse as ApiResponse
from team_member_server_sdk.api_client import ApiClient as ApiClient
from team_member_server_sdk.configuration import Configuration as Configuration
from team_member_server_sdk.exceptions import OpenApiException as OpenApiException
from team_member_server_sdk.exceptions import ApiTypeError as ApiTypeError
from team_member_server_sdk.exceptions import ApiValueError as ApiValueError
from team_member_server_sdk.exceptions import ApiKeyError as ApiKeyError
from team_member_server_sdk.exceptions import ApiAttributeError as ApiAttributeError
from team_member_server_sdk.exceptions import ApiException as ApiException

# import models into sdk package
from team_member_server_sdk.models.action_code import ActionCode as ActionCode
from team_member_server_sdk.models.action_operation import ActionOperation as ActionOperation
from team_member_server_sdk.models.action_to_update import ActionToUpdate as ActionToUpdate
from team_member_server_sdk.models.activate_team_member_request import ActivateTeamMemberRequest as ActivateTeamMemberRequest
from team_member_server_sdk.models.add_team_member_role_request import AddTeamMemberRoleRequest as AddTeamMemberRoleRequest
from team_member_server_sdk.models.disable_team_member_request import DisableTeamMemberRequest as DisableTeamMemberRequest
from team_member_server_sdk.models.enable_team_member_request import EnableTeamMemberRequest as EnableTeamMemberRequest
from team_member_server_sdk.models.entity_settings_to_update import EntitySettingsToUpdate as EntitySettingsToUpdate
from team_member_server_sdk.models.entity_type import EntityType as EntityType
from team_member_server_sdk.models.http_validation_error import HTTPValidationError as HTTPValidationError
from team_member_server_sdk.models.invite_team_member_request import InviteTeamMemberRequest as InviteTeamMemberRequest
from team_member_server_sdk.models.location_inner import LocationInner as LocationInner
from team_member_server_sdk.models.portal_member_schema import PortalMemberSchema as PortalMemberSchema
from team_member_server_sdk.models.remove_team_member_request import RemoveTeamMemberRequest as RemoveTeamMemberRequest
from team_member_server_sdk.models.remove_team_member_role_request import RemoveTeamMemberRoleRequest as RemoveTeamMemberRoleRequest
from team_member_server_sdk.models.resend_invitation_email_request import ResendInvitationEmailRequest as ResendInvitationEmailRequest
from team_member_server_sdk.models.scope_schema import ScopeSchema as ScopeSchema
from team_member_server_sdk.models.settings_operation import SettingsOperation as SettingsOperation
from team_member_server_sdk.models.team_member_access_response import TeamMemberAccessResponse as TeamMemberAccessResponse
from team_member_server_sdk.models.team_member_actions_request import TeamMemberActionsRequest as TeamMemberActionsRequest
from team_member_server_sdk.models.team_member_amount_request import TeamMemberAmountRequest as TeamMemberAmountRequest
from team_member_server_sdk.models.team_member_request import TeamMemberRequest as TeamMemberRequest
from team_member_server_sdk.models.team_member_response import TeamMemberResponse as TeamMemberResponse
from team_member_server_sdk.models.team_member_role_response import TeamMemberRoleResponse as TeamMemberRoleResponse
from team_member_server_sdk.models.team_member_role_schema import TeamMemberRoleSchema as TeamMemberRoleSchema
from team_member_server_sdk.models.team_member_role_values_to_update import TeamMemberRoleValuesToUpdate as TeamMemberRoleValuesToUpdate
from team_member_server_sdk.models.team_member_values_to_update import TeamMemberValuesToUpdate as TeamMemberValuesToUpdate
from team_member_server_sdk.models.update_team_member_request import UpdateTeamMemberRequest as UpdateTeamMemberRequest
from team_member_server_sdk.models.update_team_member_role_actions_request import UpdateTeamMemberRoleActionsRequest as UpdateTeamMemberRoleActionsRequest
from team_member_server_sdk.models.update_team_member_role_entity_settings_request import UpdateTeamMemberRoleEntitySettingsRequest as UpdateTeamMemberRoleEntitySettingsRequest
from team_member_server_sdk.models.update_team_member_role_request import UpdateTeamMemberRoleRequest as UpdateTeamMemberRoleRequest
from team_member_server_sdk.models.validation_error import ValidationError as ValidationError
from team_member_server_sdk.models.wrapped_response_int import WrappedResponseInt as WrappedResponseInt
from team_member_server_sdk.models.wrapped_response_list_team_member_response import WrappedResponseListTeamMemberResponse as WrappedResponseListTeamMemberResponse
from team_member_server_sdk.models.wrapped_response_list_team_member_role_response import WrappedResponseListTeamMemberRoleResponse as WrappedResponseListTeamMemberRoleResponse
from team_member_server_sdk.models.wrapped_response_team_member_access_response import WrappedResponseTeamMemberAccessResponse as WrappedResponseTeamMemberAccessResponse
from team_member_server_sdk.models.wrapped_response_team_member_response import WrappedResponseTeamMemberResponse as WrappedResponseTeamMemberResponse
from team_member_server_sdk.models.wrapped_response_team_member_role_response import WrappedResponseTeamMemberRoleResponse as WrappedResponseTeamMemberRoleResponse
